@@ -351,7 +351,7 @@ connect_callback (BluetoothClient *_client,
 	}
 
 	if (success == FALSE)
-		g_warning ("Failed to connect to device %s, please file a bug", data->path);
+		g_message ("Failed to connect to device %s", data->path);
 
 	g_timer_destroy (data->timer);
 	g_free (data->path);
@@ -546,7 +546,11 @@ void prepare_callback (GtkWidget *assistant,
 		if (automatic_pincode == FALSE && target_ssp == FALSE) {
 			char *text;
 
-			text = g_strdup_printf (_("Please enter the following PIN on '%s':"), target_name);
+			if (target_type == BLUETOOTH_TYPE_KEYBOARD) {
+				text = g_strdup_printf (_("Please enter the following PIN on '%s' and press “Enter” on the keyboard:"), target_name);
+			} else {
+				text = g_strdup_printf (_("Please enter the following PIN on '%s':"), target_name);
+			}
 			gtk_label_set_markup(GTK_LABEL(label_pin_help), text);
 			g_free (text);
 			set_large_label (GTK_LABEL (label_pin), pincode);
@@ -771,6 +775,7 @@ select_device_changed (BluetoothChooser *selector,
 
 	target_type = type;
 	target_ssp = !legacypairing;
+	automatic_pincode = FALSE;
 
 	g_free (pincode);
 	pincode = NULL;
